my $app = Zim::GUI->current();

eval 'use Zim::GUI::Spell';
if ($@) {
	$app->error_dialog(
		"Failed to load Spell plugin,\n".
		"do you have Gtk2::Spell installed ?", $@);
	$app->unplug('Spell');
	return 1;
}

my $spell = Zim::GUI::Spell->new(app => $app);
$app->add_object(Spell => $spell);

1;
